@@ -5,3 +5,5 @@ from gwaslab.mqqplot import mqqplot
 from gwaslab.qqplot import gc
 from gwaslab.get_hapmap3 import ldsc
 from gwaslab.h2_conversion import h2_obs_to_liab
+from gwaslab.compare_effect import compare_effect
+from gwaslab.read_ldsc import read_ldsc
